==========
chibi_site
==========


.. image:: https://img.shields.io/pypi/v/chibi_site.svg
        :target: https://pypi.python.org/pypi/chibi_site

.. image:: https://readthedocs.org/projects/chibi-site/badge/?version=latest
        :target: https://chibi-site.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status




libreria para hacer scrappers de sitios web


* Free software: WTFPL
* Documentation: https://chibi-site.readthedocs.io.


Features
--------

* TODO
